@@ -410,6 +410,9 @@ void pidgin_setup_screenname_autocomplete(GtkWidget *entry, GtkWidget *optmenu,
  * @param filesel The file selection window.
  *
  * @return TRUE if given path is a directory, FALSE otherwise.
+ * @deprecated Pidgin no longer uses GtkFileSelection internally. It has also
+ *             been deprecated by GTK+. Use GtkFileChooser instead and ignore
+ *             this function.
  */
 gboolean pidgin_check_if_dir(const char *path, GtkFileSelection *filesel);
 
@@ -714,6 +717,17 @@ GtkWidget *pidgin_make_mini_dialog(PurpleConnection *handle,
 	const char* stock_id, const char *primary, const char *secondary,
 	void *user_data, ...) G_GNUC_NULL_TERMINATED;
 
+/**
+ * Does exactly what pidgin_make_mini_dialog() does, except you can specify
+ * a custom icon for the dialog.
+ */
+GtkWidget *pidgin_make_mini_dialog_with_custom_icon(PurpleConnection *gc,
+	GdkPixbuf *custom_icon,
+	const char *primary,
+	const char *secondary,
+	void *user_data,
+	...) G_GNUC_NULL_TERMINATED;
+
 /**
  * This is a callback function to be used for Ctrl+F searching in treeviews.
  * Sample Use:
